@@ -24,14 +24,6 @@ pub(crate) struct Response {
 
 /// Consume some lines, return some highlighted text
 pub(crate) trait LinesHighlighter {
-    /// Create a new LinesHighlighter from a line of input.
-    ///
-    /// Returns None if this line doesn't start a new LinesHighlighter.
-    #[must_use]
-    fn from_line(line: &str) -> Option<Self>
-    where
-        Self: Sized;
-
     /// Consume one line of input.
     ///
     /// May or may not return a highlighted string.
@@ -43,3 +35,9 @@ pub(crate) trait LinesHighlighter {
     // No more lines available
     fn consume_eof(&mut self, thread_pool: &ThreadPool) -> Result<Vec<StringFuture>, String>;
 }
+
+impl std::fmt::Debug for dyn LinesHighlighter {
+    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+        return write!(f, "LinesHighlighter");
+    }
+}
